BalderHub FileOps
=================

.. note::
   Please note, this package is still under development. If you would like to contribute, take a look into the
   `project <https://github.com/balder-dev/balderhub-fileops/>`_.

This is a BalderHub package for the `Balder <https://docs.balder.dev/>`_ test framework. If you are new to Balder check
out the `official documentation <https://docs.balder.dev>`_ first.

What can you do with this project?
----------------------------------

.. code-block:: shell


.. toctree::
   :maxdepth: 2

   installation.rst
   topic_intro.rst
   scenarios.rst
   features.rst
   examples.rst
   utilities.rst
